# Valle 6 steps package

The program can be used to help middle school and first/second year high school students to improve their writing and pronunciation in English. In order to do so, the teacher gives them a noun, which is used as first input. Using two Datamuse APIs, the students will get some collocations (adjectives + other words commonly combined with the given noun). They will then get from the teacher some «banned words», which are words that students can’t use in their text. The following input is a sentence given by the teacher, which represents the beginning of the text that each student has to write. The text, of about 50 words, must contain at least 5 collocations obtained from Datamuse but no banned words. Should the banned word be used, then the student gets a message telling him to revise the text. If the text has no banned words it is automatically corrected by gingerbit. Once gingerbit gives back a corrected text, the student has to use this text as an input so as to get the text pronounced in British English.

To call the program: 
start_sixsteps()